# mkdocs-jupyter Change Log

## Unreleased

- Support Python 3.9
- Use new JupyterLab template as base

## 0.16.0

- Support plain Python `.py` using Jupytext

## 0.15.0

- Support nbconvert 6.0.0

## 0.13.0

- Fixed TOC in mkdocs 1.1.0
- Added the ability to include the source notebooks as part of the build
